@@ -4,11 +4,10 @@ from flask import Markup
 
 class TwitterOEmbedder(object):
     
-    def __init__(self, app=None, cache=None):
+    def __init__(self, app=None, cache=None, debug=None):
         if app is not None and cache is not None:
-            self.init(app, cache)
-    
-    def init(self, app, cache):
+            self.init(app, cache, debug)
+    def init(self, app, cache, debug=None):
         @app.context_processor
         def tweet_processor():
             @cache.memoize(timeout=60*60*24*356)
@@ -20,6 +19,12 @@ class TwitterOEmbedder(object):
                 url = 'https://api.twitter.com/1.1/statuses/oembed.json'
                 payload = {'id':tweet_id}
                 r = requests.get(url, params=payload, auth=auth)
-                tweet_html = Markup(r.json()[u'html'])
+                try:
+                    tweet_html = Markup(r.json()[u'html'])
+                except KeyError as e:
+                    if debug or (debug is None and app.debug):
+                        raise e
+                    else:
+                        return ''
                 return tweet_html
             return dict(oembed_tweet=oembed_tweet)
\ No newline at end of file
